# Hessian

::: asdex.hessian
::: asdex.value_and_hessian
::: asdex.hessian_from_coloring
::: asdex.value_and_hessian_from_coloring
::: asdex.hessian_coloring
::: asdex.hessian_coloring_from_sparsity
::: asdex.hessian_sparsity
::: asdex.check_hessian_correctness

---

::: asdex.HessianMode
